@@ -7,11 +7,30 @@ use Data::Dump qw( dump );
 
 __PACKAGE__->config( namespace => '' );
 
+sub debug_session_and_user {
+    my ( $self, $c ) = @_;
+
+    $c->log->debug( dump $c->session ) if $c->debug;  # trigger session id set
+
+    $c->log->debug(
+        "user = " . ( $c->user ? $c->user->id : '[ no user in $c ]' ) )
+        if $c->debug;
+
+}
+
 sub auto : Private {
     my ( $self, $c ) = @_;
 
     # validate the ticket and update ticket and session if necessary
-    return 1 if $c->authenticate;
+    if ( $c->authenticate ) {
+        $c->log->debug("authn ok") if $c->debug;
+        $self->debug_session_and_user($c);
+        return 1;
+    }
+    else {
+        $c->log->debug("authn failed") if $c->debug;
+        $self->debug_session_and_user($c);
+    }
 
     # no valid login found so redirect.
     $c->response->redirect( $c->config->{authentication}->{auth_url} );
